@@ -489,11 +489,11 @@ class DataTransformerForm(BaseInlineFormSet):
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
         dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self,
-                                                             fk_name='data_transformer_parent',
+                                                             fk_name='parent',
                                                              extra=1, exclude=['updated_at', 'created_at'],
-                                                             form=self.DataTransform)
+                                                             form=DataTransform)
         form.nested_data_transformer_form = dataTransformerInlineFormset(
-            initial=form.instance.getChildren(),
+            instance=form.instance,
             data=form.data if form.is_bound else None,
             files=form.files if form.is_bound else None,
             extra=1)
@@ -528,7 +528,7 @@ class DataTransform(forms.ModelForm):
     accessory = forms.CharField(required=False,
                                 widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
-    data_transformer_parent = forms.CharField(required=False,
+    parent = forms.CharField(required=False,
                                               widget=forms.HiddenInput(attrs={'class': 'form-control'}))
     type = forms.CharField(required=False,
                            widget=forms.TextInput(attrs={'class': 'form-control'}))
@@ -570,5 +570,5 @@ class DataTransform(forms.ModelForm):
 
     class Meta:
         model = DataTransformer
-        fields = ['id','accessory','data_transformer_parent','type']
+        fields = ['id','accessory','parent','type']
 # DataTransformerFormset = form_factory(DataTransformer,formset=DataTransformerForm)
