@@ -3,7 +3,7 @@ import uuid
 from django.utils import timezone
 import time
 from polymorphic.models import PolymorphicModel
-
+from mptt.models import MPTTModel, TreeForeignKey
 
 class Hub(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
@@ -251,7 +251,11 @@ class Accessory(models.Model):
 
     @property
     def has_data_transformer(self):
-        return hasattr(self, 'datatransformer') or hasattr(self, 'data_transformer')
+        return hasattr(self, 'datatransformer_set') or hasattr(self, 'data_transformer_set')
+
+    @property
+    def datatransformer(self):
+        return self.datatransformer_set.first().get_root()
 
     class Meta:
         indexes = [
@@ -302,15 +306,15 @@ class HardwareStats(models.Model):
 
 
 
-class DataTransformer(models.Model):
+class DataTransformer(MPTTModel):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
-    accessory = models.OneToOneField(
+    accessory = models.ForeignKey(
         Accessory,
         on_delete=models.CASCADE,
         blank = False,
         null=False
     )
-    data_transformer_parent = models.ForeignKey('self', on_delete=models.CASCADE, blank=True, null=True, default=None)
+    parent = TreeForeignKey('self', on_delete=models.CASCADE, null=True, blank=True, related_name='children')
     type = models.CharField(max_length=255,  blank=True, null=True, default=None)
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
