@@ -76,9 +76,9 @@ urlpatterns = [
     path('hub/', csrf_exempt(HubViewSet.postHub)),
     path('pipico/', csrf_exempt(HardwareViewSet.postHardware)),
 
-    path('hubs/<uuid:hub_id>/hardwares', listHubHardware),
-    path('hubs/<uuid:hub_id>/channels', listHubChannels),
-    path('hubs/<uuid:hub_id>/accessories', listHubAccessories),
+    path('hubs/<uuid:hub_id>/hardwares', view=listHubHardware),
+    path('hubs/<uuid:hub_id>/channels', view=listHubChannels),
+    path('hubs/<uuid:hub_id>/accessories', view=listHubAccessories),
     path('openhubapi/about', HubViewSet.about),
     path('streams/', video_streams, name="video_streams"),
     url(r'^signup/$', signup, name='signup'),
