@@ -410,7 +410,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
                  "data_transformer_form": formset},
                 template_name='accessory.html')
         else:
-            return super(AccessoryViewSet, self).retrieve()
+            return super(AccessoryViewSet, self).retrieve(request, *args, **kwargs)
 
     def postAccessory(request):
         # request should be ajax and method should be POST.
